@@ -1,4 +1,5 @@
 from typing import Optional, Iterable, Tuple, Callable, Union
+from functools import partial
 import random
 from pathlib import Path
 import numpy as np
@@ -94,7 +95,7 @@ def add_multiscale_output_layer(
         root,
         source_axes=axes,
         data_group=data_group,
-        scale=4,
+        scale=2,
         num_scales=5,
         reference_source_axes=reference_source_axes,
         reference_scale=reference_scale
@@ -246,7 +247,7 @@ class FineTuningMethod:
             dataset = zds.ZarrDataset(
                 list(dataset_metadata.values()),
                 return_positions=False,
-                draw_same_chunk=True,
+                draw_same_chunk=False,
                 patch_sampler=StaticPatchSampler(
                     patch_size=patch_sizes,
                     top_lefts=top_lefts,
@@ -255,6 +256,8 @@ class FineTuningMethod:
                 shuffle=True,
             )
 
+            dataset.add_transform("images", zds.ToDtype(np.float32))
+
             if USING_PYTORCH:
                 dataloader = DataLoader(
                     dataset,
@@ -352,7 +355,7 @@ class AcquisitionFunction:
             dataset_metadata[layer_type] = layers_group.metadata
             dataset_metadata[layer_type]["roi"] = None
 
-            if "images" in layer_type:
+            if layer_type in ["images", "labels"]:
                 dataset_metadata[layer_type]["roi"] = [tuple(
                     slice(0, ax_s - ax_s % self._patch_sizes.get(ax, 1))
                     if (ax != "C"
@@ -361,6 +364,8 @@ class AcquisitionFunction:
                     else slice(None)
                     for ax, ax_s in zip(displayed_source_axes,
                                         displayed_shape)
+                    if (layer_type == "images"
+                        or (layer_type == "labels" and ax != "C"))
                 )]
 
             if isinstance(dataset_metadata[layer_type]["filenames"],
