@@ -869,6 +869,14 @@ class ImageGroupRoot(QTreeWidgetItem):
             if not image_group.childCount():
                 self.removeChild(image_group)
 
+            if image_group.labels_group:
+                if image_group.labels_group.parent():
+                    image_group.labels_group.parent().removeChild(
+                        image_group.labels_group
+                    )
+
+                image_group.labels_group = None
+
         if not self.managed_layers[removed_layer]:
             self.managed_layers.pop(removed_layer)
 
@@ -1497,4 +1505,9 @@ class ImageGroupsManager:
             with open(self._active_image_group.group_dir
                       / (self._active_image_group.group_name
                          + "_metadata.json"), "w") as fp:
-                fp.write(json.dumps(self._active_image_group.metadata))
+                try:
+                    fp.write(json.dumps(self._active_image_group.metadata))
+                except TypeError:
+                    raise ValueError("Some images in this group are arrays, "
+                                     "save them as zarr files to generate the"
+                                     "metadata file.")
